gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnunet] 47/90: -DOC: Documentation cleanup pass through RECLAIM subsyst


From: gnunet
Subject: [gnunet] 47/90: -DOC: Documentation cleanup pass through RECLAIM subsystem
Date: Tue, 18 Oct 2022 03:06:46 +0200

This is an automated email from the git hooks/post-receive script.

martin-schanzenbach pushed a commit to branch master
in repository gnunet.

commit 2803abe19c6c65c1a98a9b69cef27b5dc363f93e
Author: Willow Liquorice <willow@howhill.com>
AuthorDate: Wed Sep 7 20:50:41 2022 +0100

    -DOC: Documentation cleanup pass through RECLAIM subsystem
---
 src/include/gnunet_reclaim_lib.h             | 14 +++++++-------
 src/include/gnunet_reclaim_service.h         |  6 +++---
 src/reclaim/gnunet-service-reclaim.c         |  2 +-
 src/reclaim/gnunet-service-reclaim_tickets.c | 10 +++++-----
 src/reclaim/oidc_helper.c                    | 11 -----------
 src/reclaim/oidc_helper.h                    |  4 ++--
 src/reclaim/reclaim_api.c                    | 19 +++---------------
 src/reclaim/reclaim_attribute.c              | 25 ++++--------------------
 src/reclaim/reclaim_credential.c             | 29 ++++++----------------------
 9 files changed, 31 insertions(+), 89 deletions(-)

diff --git a/src/include/gnunet_reclaim_service.h 
b/src/include/gnunet_reclaim_service.h
index b80436e6b..e9e0f144d 100644
--- a/src/include/gnunet_reclaim_service.h
+++ b/src/include/gnunet_reclaim_service.h
@@ -200,7 +200,7 @@ GNUNET_RECLAIM_attribute_store (
    *
    * @param h handle to the re:claimID service
    * @param pkey private key of the identity
-   * @param attr the credential value
+   * @param credential the credential value
    * @param exp_interval the relative expiration interval for the credential
    * @param cont continuation to call when done
    * @param cont_cls closure for @a cont
@@ -349,7 +349,7 @@ GNUNET_RECLAIM_get_credentials_start (
  * Calls the record processor specified in 
#GNUNET_RECLAIM_get_credentials_start
  * for the next record.
  *
- * @param it the iterator
+ * @param ait the iterator
  */
 void
 GNUNET_RECLAIM_get_credentials_next (
@@ -361,7 +361,7 @@ GNUNET_RECLAIM_get_credentials_next (
  * be called on any iteration that has not yet completed prior to calling
  * #GNUNET_RECLAIM_disconnect.
  *
- * @param it the iterator
+ * @param ait the iterator
  */
 void
 GNUNET_RECLAIM_get_credentials_stop (
diff --git a/src/reclaim/gnunet-service-reclaim.c 
b/src/reclaim/gnunet-service-reclaim.c
index 9f035f1bd..5290621d6 100644
--- a/src/reclaim/gnunet-service-reclaim.c
+++ b/src/reclaim/gnunet-service-reclaim.c
@@ -522,7 +522,7 @@ cleanup_adh (struct AttributeDeleteHandle *adh)
 /**
  * Cleanup attribute store handle
  *
- * @param handle handle to clean up
+ * @param ash handle to clean up
  */
 static void
 cleanup_as_handle (struct AttributeStoreHandle *ash)
diff --git a/src/reclaim/gnunet-service-reclaim_tickets.c 
b/src/reclaim/gnunet-service-reclaim_tickets.c
index 3fc885aaf..a17dfb0e2 100644
--- a/src/reclaim/gnunet-service-reclaim_tickets.c
+++ b/src/reclaim/gnunet-service-reclaim_tickets.c
@@ -485,7 +485,7 @@ rvk_ticket_update_finished (void *cls)
  * @param cls handle to the operation
  * @param zone ticket issuer private key
  * @param label ticket rnd
- * @param rd_cound size of record set
+ * @param rd_count size of record set
  * @param rd record set
  */
 static void
@@ -569,7 +569,7 @@ rvk_ns_err (void *cls)
  * When we are done, we need to update any other ticket which
  * included references to any of the changed attributes.
  *
- * @param rvk handle to the operation
+ * @param rh handle to the operation
  */
 static void
 move_attrs (struct RECLAIM_TICKETS_RevokeHandle *rh);
@@ -835,7 +835,7 @@ remove_ticket_cont (void *cls, int32_t success, const char 
*emsg)
  * @param cls handle to the operation
  * @param zone the issuer key
  * @param label ticket rnd
- * @param rd_cound size of record set
+ * @param rd_count size of record set
  * @param rd record set
  */
 static void
@@ -986,7 +986,7 @@ cleanup_cth (struct RECLAIM_TICKETS_ConsumeHandle *cth)
  * We found an attribute record.
  *
  * @param cls handle to the operation
- * @param rd_cound size of record set
+ * @param rd_count size of record set
  * @param rd record set
  */
 static void
@@ -1074,7 +1074,7 @@ abort_parallel_lookups (void *cls)
  * attribute record under the referenced label.
  *
  * @param cls handle to the operation
- * @param rd_cound size of the record set
+ * @param rd_count size of the record set
  * @param rd record set
  */
 static void
diff --git a/src/reclaim/oidc_helper.c b/src/reclaim/oidc_helper.c
index c87514a6b..647ebe302 100644
--- a/src/reclaim/oidc_helper.c
+++ b/src/reclaim/oidc_helper.c
@@ -424,17 +424,6 @@ generate_id_token_body (const struct 
GNUNET_IDENTITY_PublicKey *aud_key,
 }
 
 
-/**
- * Create a JWT using RSA256 algorithm from attributes
- *
- * @param aud_key the public of the audience
- * @param sub_key the public key of the subject
- * @param attrs the attribute list
- * @param presentations credential presentation list (may be empty)
- * @param expiration_time the validity of the token
- * @param secret_rsa_key the key used to sign the JWT
- * @return a new base64-encoded JWT string.
- */
 char *
 OIDC_generate_id_token_rsa (const struct GNUNET_IDENTITY_PublicKey *aud_key,
                             const struct GNUNET_IDENTITY_PublicKey *sub_key,
diff --git a/src/reclaim/oidc_helper.h b/src/reclaim/oidc_helper.h
index 21c7aa86e..81eadf2ed 100644
--- a/src/reclaim/oidc_helper.h
+++ b/src/reclaim/oidc_helper.h
@@ -50,14 +50,14 @@ enum OIDC_VerificationOptions
 };
 
 /**
- * Create a JWT using RSA256 from attributes
+ * Create a JWT using RSA256 algorithm from attributes
  *
  * @param aud_key the public of the audience
  * @param sub_key the public key of the subject
  * @param attrs the attribute list
  * @param presentations credential presentation list (may be empty)
  * @param expiration_time the validity of the token
- * @param secret_key the key used to sign the JWT
+ * @param secret_rsa_key the key used to sign the JWT
  * @return a new base64-encoded JWT string.
  */
 char *
diff --git a/src/reclaim/reclaim_api.c b/src/reclaim/reclaim_api.c
index a61505d62..6f55d62e4 100644
--- a/src/reclaim/reclaim_api.c
+++ b/src/reclaim/reclaim_api.c
@@ -1206,7 +1206,7 @@ struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_credential_store (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_IDENTITY_PrivateKey *pkey,
-  const struct GNUNET_RECLAIM_Credential *attr,
+  const struct GNUNET_RECLAIM_Credential *credential,
   const struct GNUNET_TIME_Relative *exp_interval,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
@@ -1221,7 +1221,7 @@ GNUNET_RECLAIM_credential_store (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_credential_serialize_get_size (attr);
+  attr_len = GNUNET_RECLAIM_credential_serialize_get_size (credential);
   op->env = GNUNET_MQ_msg_extra (sam,
                                  attr_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_CREDENTIAL_STORE);
@@ -1229,7 +1229,7 @@ GNUNET_RECLAIM_credential_store (
   sam->id = htonl (op->r_id);
   sam->exp = GNUNET_htonll (exp_interval->rel_value_us);
 
-  GNUNET_RECLAIM_credential_serialize (attr, (char *) &sam[1]);
+  GNUNET_RECLAIM_credential_serialize (credential, (char *) &sam[1]);
 
   sam->attr_len = htons (attr_len);
   if (NULL != h->mq)
@@ -1439,12 +1439,6 @@ GNUNET_RECLAIM_get_credentials_start (
 }
 
 
-/**
- * Calls the record processor specified in #GNUNET_RECLAIM_get_credential_start
- * for the next record.
- *
- * @param it the iterator
- */
 void
 GNUNET_RECLAIM_get_credentials_next (struct
                                      GNUNET_RECLAIM_CredentialIterator *ait)
@@ -1460,13 +1454,6 @@ GNUNET_RECLAIM_get_credentials_next (struct
 }
 
 
-/**
- * Stops iteration and releases the handle for further calls. Must
- * be called on any iteration that has not yet completed prior to calling
- * #GNUNET_RECLAIM_disconnect.
- *
- * @param it the iterator
- */
 void
 GNUNET_RECLAIM_get_credentials_stop (struct
                                      GNUNET_RECLAIM_CredentialIterator *ait)
diff --git a/src/reclaim/reclaim_attribute.c b/src/reclaim/reclaim_attribute.c
index 5d7adb7e6..b5c41b2d1 100644
--- a/src/reclaim/reclaim_attribute.c
+++ b/src/reclaim/reclaim_attribute.c
@@ -325,16 +325,9 @@ GNUNET_RECLAIM_attribute_list_serialize_get_size (
 }
 
 
-/**
- * Serialize an attribute list
- *
- * @param attrs the attribute list to serialize
- * @param result the serialized attribute
- * @return length of serialized data
- */
 size_t
 GNUNET_RECLAIM_attribute_list_serialize (
-  const struct GNUNET_RECLAIM_AttributeList *al,
+  const struct GNUNET_RECLAIM_AttributeList *attrs,
   char *result)
 {
   struct GNUNET_RECLAIM_AttributeListEntry *ale;
@@ -343,7 +336,7 @@ GNUNET_RECLAIM_attribute_list_serialize (
   char *write_ptr;
   write_ptr = result;
   total_len = 0;
-  for (ale = al->list_head; NULL != ale; ale = ale->next)
+  for (ale = attrs->list_head; NULL != ale; ale = ale->next)
   {
     GNUNET_assert (NULL != ale->attribute);
     len = GNUNET_RECLAIM_attribute_serialize (ale->attribute, write_ptr);
@@ -396,21 +389,16 @@ GNUNET_RECLAIM_attribute_list_deserialize (const char 
*data, size_t data_size)
 }
 
 
-/**
- * Make a (deep) copy of a claim list
- * @param attrs claim list to copy
- * @return copied claim list
- */
 struct GNUNET_RECLAIM_AttributeList *
 GNUNET_RECLAIM_attribute_list_dup (
-  const struct GNUNET_RECLAIM_AttributeList *al)
+  const struct GNUNET_RECLAIM_AttributeList *attrs)
 {
   struct GNUNET_RECLAIM_AttributeListEntry *ale;
   struct GNUNET_RECLAIM_AttributeListEntry *result_ale;
   struct GNUNET_RECLAIM_AttributeList *result;
 
   result = GNUNET_new (struct GNUNET_RECLAIM_AttributeList);
-  for (ale = al->list_head; NULL != ale; ale = ale->next)
+  for (ale = attrs->list_head; NULL != ale; ale = ale->next)
   {
     result_ale = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
     GNUNET_assert (NULL != ale->attribute);
@@ -433,11 +421,6 @@ GNUNET_RECLAIM_attribute_list_dup (
 }
 
 
-/**
- * Destroy claim list
- *
- * @param attrs list to destroy
- */
 void
 GNUNET_RECLAIM_attribute_list_destroy (
   struct GNUNET_RECLAIM_AttributeList *al)
diff --git a/src/reclaim/reclaim_credential.c b/src/reclaim/reclaim_credential.c
index b1312f403..6dc1a1fcf 100644
--- a/src/reclaim/reclaim_credential.c
+++ b/src/reclaim/reclaim_credential.c
@@ -301,13 +301,6 @@ GNUNET_RECLAIM_credential_list_serialize_get_size (
 }
 
 
-/**
- * Serialize an attribute list
- *
- * @param attrs the attribute list to serialize
- * @param result the serialized attribute
- * @return length of serialized data
- */
 size_t
 GNUNET_RECLAIM_credential_list_serialize (
   const struct GNUNET_RECLAIM_CredentialList *credentials,
@@ -399,19 +392,14 @@ GNUNET_RECLAIM_credential_list_dup (
 }
 
 
-/**
- * Destroy credential list
- *
- * @param attrs list to destroy
- */
 void
 GNUNET_RECLAIM_credential_list_destroy (
-  struct GNUNET_RECLAIM_CredentialList *al)
+  struct GNUNET_RECLAIM_CredentialList *credentials)
 {
   struct GNUNET_RECLAIM_CredentialListEntry *ale;
   struct GNUNET_RECLAIM_CredentialListEntry *tmp_ale;
 
-  for (ale = al->list_head; NULL != ale;)
+  for (ale = credentials->list_head; NULL != ale;)
   {
     if (NULL != ale->credential)
       GNUNET_free (ale->credential);
@@ -419,7 +407,7 @@ GNUNET_RECLAIM_credential_list_destroy (
     ale = ale->next;
     GNUNET_free (tmp_ale);
   }
-  GNUNET_free (al);
+  GNUNET_free (credentials);
 }
 
 
@@ -826,19 +814,14 @@ GNUNET_RECLAIM_presentation_list_dup (
 }
 
 
-/**
- * Destroy presentation list
- *
- * @param attrs list to destroy
- */
 void
 GNUNET_RECLAIM_presentation_list_destroy (
-  struct GNUNET_RECLAIM_PresentationList *al)
+  struct GNUNET_RECLAIM_PresentationList *presentations)
 {
   struct GNUNET_RECLAIM_PresentationListEntry *ale;
   struct GNUNET_RECLAIM_PresentationListEntry *tmp_ale;
 
-  for (ale = al->list_head; NULL != ale;)
+  for (ale = presentations->list_head; NULL != ale;)
   {
     if (NULL != ale->presentation)
       GNUNET_free (ale->presentation);
@@ -846,7 +829,7 @@ GNUNET_RECLAIM_presentation_list_destroy (
     ale = ale->next;
     GNUNET_free (tmp_ale);
   }
-  GNUNET_free (al);
+  GNUNET_free (presentations);
 }
 
 

diff --git a/src/include/gnunet_reclaim_lib.h b/src/include/gnunet_reclaim_lib.h
index 0d5ef59b7..35b58cd0e 100644
--- a/src/include/gnunet_reclaim_lib.h
+++ b/src/include/gnunet_reclaim_lib.h
@@ -515,7 +515,7 @@ GNUNET_RECLAIM_attribute_number_to_typename (uint32_t type);
 /**
  * Get required size for serialization buffer
  *
  * @param attrs the attribute list to serialize
  * @return the required buffer size
  */
 size_t
@@ -524,9 +524,9 @@ GNUNET_RECLAIM_credential_list_serialize_get_size (
 
 
 /**
- * Destroy claim list
+ * Destroy credential list
  *
  * @param attrs list to destroy
  */
 void
 GNUNET_RECLAIM_credential_list_destroy (
@@ -551,15 +551,15 @@ GNUNET_RECLAIM_credential_list_add (
 
 
 /**
- * Serialize an attribute list
+ * Serialize a credential list
  *
  * @param attrs the attribute list to serialize
  * @param result the serialized attribute
  * @return length of serialized data
  */
 size_t
 GNUNET_RECLAIM_credential_list_serialize (
-  const struct GNUNET_RECLAIM_CredentialList *attrs,
+  const struct GNUNET_RECLAIM_CredentialList *credentials,
   char *result);
 
 
@@ -515,7 +515,7 @@ GNUNET_RECLAIM_attribute_number_to_typename (uint32_t type);
  * Get required size for serialization buffer
  *
- * @param attrs the attribute list to serialize
+ * @param credentials the attribute list to serialize
  * @return the required buffer size
  */
@@ -524,9 +524,9 @@ GNUNET_RECLAIM_credential_list_serialize_get_size (
  *
- * @param attrs list to destroy
+ * @param credentials list to destroy
  */
 void
@@ -551,15 +551,15 @@ GNUNET_RECLAIM_credential_list_add (
  *
- * @param attrs the attribute list to serialize
- * @param result the serialized attribute
+ * @param credentials the credential list to serialize
+ * @param result the serialized credential
  * @return length of serialized data
  */
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]